
/**
 * Get Newsarchive options
 * @returns {string}
 */
function getNewsArchiveOptions() {
    var aNewsData = tinyMCE.activeEditor.getParam('newslink_news_data');
    var options = '';
    Array.each(aNewsData['archives'], function (aArchive) {
        options += '<option value="' + aArchive['value'] + '">' + aArchive['text'] + '</option>';
    });

    return options;

}
/**
 * Get News options
 * @param pid
 * @returns {string}
 */
function getNewsOptions(pid) {
    var aNewsData = tinyMCE.activeEditor.getParam('newslink_news_data');
    var options = '';
    Array.each(aNewsData['news']['archive_' + pid], function (aNews) {
        options += '<option value="' + aNews['value'] + '">' + aNews['text'] + '</option>';
    });

    return options;

}





// Add button to the toolbar
tinymce.PluginManager.add("newslink", function (editor, url) {

    editor.on('init', function() {
        // Get language-data from tinyCustom.php
        var langCode = tinymce.util.I18n.getCode();
        var langData = tinyMCE.activeEditor.getParam('newslink_language_data');
        // Adds translations for a specific language code. --> http://archive.tinymce.com/wiki.php/api4:method.tinymce.util.I18n.add
        tinymce.util.I18n.add(langCode, langData);
    });
    // Add a button that opens a window
    editor.addButton('newslink', {
        icon: 'newslink',
        tooltip: 'insert-news-link',
        onclick: function () {

            var aNewsData = tinyMCE.activeEditor.getParam('newslink_news_data');
            var pid = aNewsData['archives'][0]['value'];

            var html = '<div style="padding:10px">';

            // Newsarchive
            html += '<h3>Newsarchiv auswählen</h3>';
            html += '<select id="newsarchives" style="width: 90%; margin-bottom: 30px;" class="tl_select tl_chosen">';
            html += getNewsArchiveOptions();
            html += '</select><p></p>';

            // News
            html += '<h3>Newsbeitrag auswählen</h3>';
            html += '<select id="newslist" style="width: 90%; margin-bottom: 30px;" name="newlist" class="tl_select tl_chosen">';
            html += getNewsOptions(pid);
            html += '</select>';

            html += '</div>';


            // Open modal window
            var SM = new SimpleModal({
                "width": 640,
                'draggable': false,
                'overlayOpacity': .5,
                'onShow': function () {
                    document.body.setStyle('overflow', 'hidden');
                },
                'onHide': function () {
                    document.body.setStyle('overflow', 'auto');
                }
            });


            // Add button and add event to the button
            SM.addButton("auswählen", "btn primary", function () {
                var id = $('newslist').getSelected().get('value');
                // Insert content when the window form is submitted
                if (id > 0) {
                    var selectedContent = tinymce.activeEditor.selection.getContent({format: 'text'}).trim();
                    if (selectedContent != '') {
                        tinymce.activeEditor.selection.setContent('<a href="{{news_url::' + id + '}}">' + selectedContent + '</a> ');
                    } else {
                        var text = 'Hier klicken!';
                        editor.insertContent('<a href="{{news_url::' + id + '}}">' + text + '</a> ');
                    }
                }
                this.hide();
            });

            // Add cancel button
            SM.addButton("Cancel", "btn");

            SM.show({
                "title": "Newsartikel auswählen",
                "contents": html
            });

            // Remove the ok-button
            $$('.simple-modal-footer a[title="OK"]').destroy();

            // Add onchange event
            document.id('newsarchives').addEvent('change', function () {
                var pid = this.getSelected().get("value");
                $$('#newslist option').destroy();
                $('newslist').appendHTML(getNewsOptions(pid));
            });
        }
    });
});
